/*********************************************************************************************
Comprehensive Baseline Collecting Solution
V1.2 - 2015.05

Written by Robert Virag

BCS_create_jobs.sql

----

For scheduling the collectors with agent jobs, Ola Hallengren's code is used
with his permission.

http://ola.hallengren.com/license.html

---

License: The solution is free: http://www.sqlapprentice.net/license/

Copyright (c) 2014 Robert Virag | SQLApprentice.net

Permission is hereby granted, free of charge, to any person 
obtaining a copy of this software and associated documentation 
files (the Software), to deal in the Software without 
restriction, including without limitation the rights to use, 
copy, modify, merge, publish, distribute, sublicense, and/or 
sell copies of the Software, and to permit persons to whom the 
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be 
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED AS IS, WITHOUT WARRANTY OF ANY KIND, 
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES 
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR 
THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*********************************************************************************************/

IF(NOT EXISTS (SELECT [name] FROM [sys].[databases] WHERE [name] = 'BaselineDB'))
BEGIN
	CREATE DATABASE [BaselineDB]
END
GO

IF OBJECT_ID (N'tempdb..#TempConfiguration' ) IS NOT NULL
BEGIN
	DROP TABLE #TempConfiguration
END

CREATE TABLE #TempConfiguration
	(
		[variable] NVARCHAR(128),
		[value] NVARCHAR(max)
	)

USE [BaselineDB]	---------------------------------------------------- modify
GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET NOCOUNT ON
GO

/*--------------------------------------------
-- Settings variables
--------------------------------------------*/
DECLARE @CreateJobs TINYINT
DECLARE @OutputFileDirectory nvarchar(max)
DECLARE @CreateSchedules TINYINT

DECLARE @SQLCommand NVARCHAR(max)
DECLARE @TableName NVARCHAR(255)
DECLARE @DataCompression BIT
DECLARE @DropTableIfExist BIT
DECLARE @DropJobsIfExist TINYINT

SET @CreateJobs = 0	---------------------------------------------------- modify
/* One log file per day per job will be created */
SET @OutputFileDirectory = N'D:\BaselineLog'	---------------- modify
/* Schedules will be DISABLED and will not be mapped to jobs!!! */
SET @CreateSchedules = 1 ----------------------------------------------- modify

SET @DropJobsIfExist = 1 ------------------------------------------- modify
SET @DropTableIfExist = 1	-------------------------------------------- modify
SET @DataCompression = 1	-------------------------------------------- modify

INSERT INTO #TempConfiguration ([variable], [value]) VALUES 
(N'@CreateJobs', CAST(@CreateJobs AS nvarchar))
INSERT INTO #TempConfiguration ([variable], [value]) VALUES 
(N'@OutputFileDirectory', @OutputFileDirectory)
INSERT INTO #TempConfiguration ([variable], [value]) VALUES 
(N'@CreateSchedules', CAST(@CreateSchedules AS nvarchar))
INSERT INTO #TempConfiguration ([variable], [value]) VALUES 
(N'@DropJobsIfExist', CAST(@DropJobsIfExist AS nvarchar))

/*------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------*/

/*********************************************************************************************
Create Jobs for the collectors

For scheduling the collectors with agent jobs, Ola Hallengren's code is used
with his permission.

http://ola.hallengren.com/license.html

*********************************************************************************************/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

DECLARE @CreateJobs TINYINT
DECLARE @OutputFileDirectory nvarchar(max)
DECLARE @drop_jobs_if_exist TINYINT

SELECT @CreateJobs = CAST(value AS TINYINT) FROM #TempConfiguration WHERE [variable] = N'@CreateJobs'

SELECT @OutputFileDirectory = value FROM #TempConfiguration WHERE [variable] = N'@OutputFileDirectory'

SELECT @drop_jobs_if_exist = CAST(value AS TINYINT) FROM #TempConfiguration WHERE [variable] = N'@DropJobsIfExist'
	

IF RIGHT(@OutputFileDirectory, 1) = N'\'
BEGIN
	SET @OutputFileDirectory = LEFT(@OutputFileDirectory, LEN(@OutputFileDirectory)-1)
END

IF SERVERPROPERTY('EngineEdition') <> 4
BEGIN
	DECLARE @JobCategory nvarchar(max)
	SET @JobCategory = N'Baseline Collector'

	IF NOT EXISTS (SELECT * FROM [msdb].[dbo].[syscategories] WHERE [category_class] = 1 AND [category_type] = 1 AND [name] = @JobCategory)
	BEGIN
		EXEC [msdb].[dbo].sp_add_category @class = N'JOB', @type = 'LOCAL', @name = @JobCategory
	END
		
	DECLARE @Version numeric(18,10)

	DECLARE @TokenServer nvarchar(max)
	DECLARE @TokenJobID nvarchar(max)
	DECLARE @TokenStepID nvarchar(max)
	DECLARE @TokenDate nvarchar(max)
	DECLARE @TokenTime nvarchar(max)
	DECLARE @TokenLogDirectory nvarchar(max)

	DECLARE @JobDescription nvarchar(max)
	DECLARE @JobOwner nvarchar(max)

	DECLARE @JobName01 nvarchar(max)
	DECLARE @JobName02 nvarchar(max)
	DECLARE @JobName03 nvarchar(max)
	DECLARE @JobName04 nvarchar(max)
	DECLARE @JobName05 nvarchar(max)
	DECLARE @JobName06 nvarchar(max)
	DECLARE @JobName07 nvarchar(max)
	DECLARE @JobName08 nvarchar(max)

	DECLARE @JobCommand01 nvarchar(max)
	DECLARE @JobCommand02 nvarchar(max)
	DECLARE @JobCommand03 nvarchar(max)
	DECLARE @JobCommand04 nvarchar(max)
	DECLARE @JobCommand05 nvarchar(max)
	DECLARE @JobCommand06 nvarchar(max)
	DECLARE @JobCommand07 nvarchar(max)
	DECLARE @JobCommand08 nvarchar(max)

	DECLARE @OutputFile01 nvarchar(max)
	DECLARE @OutputFile02 nvarchar(max)
	DECLARE @OutputFile03 nvarchar(max)
	DECLARE @OutputFile04 nvarchar(max)
	DECLARE @OutputFile05 nvarchar(max)
	DECLARE @OutputFile06 nvarchar(max)
	DECLARE @OutputFile07 nvarchar(max)
	DECLARE @OutputFile08 nvarchar(max)

	SET @Version = CAST(LEFT(CAST(SERVERPROPERTY('ProductVersion') AS nvarchar(max)),CHARINDEX('.',CAST(SERVERPROPERTY('ProductVersion') AS nvarchar(max))) - 1) + '.' + REPLACE(RIGHT(CAST(SERVERPROPERTY('ProductVersion') AS nvarchar(max)), LEN(CAST(SERVERPROPERTY('ProductVersion') AS nvarchar(max))) - CHARINDEX('.',CAST(SERVERPROPERTY('ProductVersion') AS nvarchar(max)))),'.','') AS numeric(18,10))

	IF @Version >= 9.002047
	BEGIN
	SET @TokenServer = '$' + '(ESCAPE_SQUOTE(SRVR))'
	SET @TokenJobID = '$' + '(ESCAPE_SQUOTE(JOBID))'
	SET @TokenStepID = '$' + '(ESCAPE_SQUOTE(STEPID))'
	SET @TokenDate = '$' + '(ESCAPE_SQUOTE(STRTDT))'
	SET @TokenTime = '$' + '(ESCAPE_SQUOTE(STRTTM))'
	END
	ELSE
	BEGIN
	SET @TokenServer = '$' + '(SRVR)'
	SET @TokenJobID = '$' + '(JOBID)'
	SET @TokenStepID = '$' + '(STEPID)'
	SET @TokenDate = '$' + '(STRTDT)'
	SET @TokenTime = '$' + '(STRTTM)'
	END

	IF @Version >= 12
	BEGIN
	SET @TokenLogDirectory = '$' + '(ESCAPE_SQUOTE(SQLLOGDIR))'
	END

	SET @JobDescription = 'Source: http://sqlapprentice.net'

	SET @JobOwner = SUSER_SNAME(0x01)

	SET @JobName01 = N'Baseline - CollectConfigData'
	IF EXISTS (SELECT * FROM msdb.dbo.sysjobs WHERE [name] = @JobName01) AND @drop_jobs_if_exist = 1
	BEGIN
		EXEC msdb.dbo.sp_delete_job @job_name = @JobName01, @delete_unused_schedule=1
	END
	IF @CreateJobs = 1
	BEGIN
		/* [sp_CollectConfigData] @Retention = 90, @BypassNonActiveSrvConfError = 1, @LogInfo = 1 */
		SET @JobCommand01 = 'sqlcmd -E -S ' + @TokenServer + ' -d ' + DB_NAME() + ' -Q "EXECUTE [dbo].[sp_CollectConfigData] @Retention = 90, @BypassNonActiveSrvConfError = 1, @LogInfo = 1" -b'
		SET @OutputFile01 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + 'Baseline_ConfigData_' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile01) > 200 SET @OutputFile01 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile01) > 200 SET @OutputFile01 = NULL

		EXECUTE msdb.dbo.sp_add_job @job_name = @JobName01, @description = @JobDescription, @category_name = @JobCategory, @owner_login_name = @JobOwner
		EXECUTE msdb.dbo.sp_add_jobstep @job_name = @JobName01, @step_name = @JobName01, @subsystem = 'CMDEXEC', @command = @JobCommand01, @output_file_name = @OutputFile01, @flags=2 
		EXECUTE msdb.dbo.sp_add_jobserver @job_name = @JobName01
	END

	SET @JobName02 = N'Baseline - CollectDatabaseInfo'
	IF EXISTS (SELECT * FROM msdb.dbo.sysjobs WHERE [name] = @JobName02) AND @drop_jobs_if_exist = 1
	BEGIN
		EXEC msdb.dbo.sp_delete_job @job_name = @JobName02, @delete_unused_schedule=1
	END
	IF @CreateJobs = 1
	BEGIN
		/* [sp_CollectDatabaseInfo] @Retention = 90, @LogInfo = 1 */
		SET @JobCommand02 = 'sqlcmd -E -S ' + @TokenServer + ' -d ' + DB_NAME() + ' -Q "EXECUTE [dbo].[sp_CollectDatabaseInfo] @Retention = 90, @LogInfo = 1" -b'
		SET @OutputFile02 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + 'Baseline_DatabaseInfo_' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile02) > 200 SET @OutputFile02 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile02) > 200 SET @OutputFile02 = NULL

		EXECUTE msdb.dbo.sp_add_job @job_name = @JobName02, @description = @JobDescription, @category_name = @JobCategory, @owner_login_name = @JobOwner
		EXECUTE msdb.dbo.sp_add_jobstep @job_name = @JobName02, @step_name = @JobName02, @subsystem = 'CMDEXEC', @command = @JobCommand02, @output_file_name = @OutputFile02, @flags=2 
		EXECUTE msdb.dbo.sp_add_jobserver @job_name = @JobName02
	END

	SET @JobName03 = N'Baseline - CollectFileInfo'
	IF EXISTS (SELECT * FROM msdb.dbo.sysjobs WHERE [name] = @JobName03) AND @drop_jobs_if_exist = 1
	BEGIN
		EXEC msdb.dbo.sp_delete_job @job_name = @JobName03, @delete_unused_schedule=1
	END
	IF @CreateJobs = 1
	BEGIN
		/* [sp_CollectFileInfo] @Retention = 90, @LogInfo = 1 */
		SET @JobCommand03 = 'sqlcmd -E -S ' + @TokenServer + ' -d ' + DB_NAME() + ' -Q "EXECUTE [dbo].[sp_CollectFileInfo] @Retention = 90, @LogInfo = 1" -b'
		SET @OutputFile03 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + 'Baseline_FileInfo_' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile03) > 200 SET @OutputFile03 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile03) > 200 SET @OutputFile03 = NULL

		EXECUTE msdb.dbo.sp_add_job @job_name = @JobName03, @description = @JobDescription, @category_name = @JobCategory, @owner_login_name = @JobOwner
		EXECUTE msdb.dbo.sp_add_jobstep @job_name = @JobName03, @step_name = @JobName03, @subsystem = 'CMDEXEC', @command = @JobCommand03, @output_file_name = @OutputFile03, @flags=2 
		EXECUTE msdb.dbo.sp_add_jobserver @job_name = @JobName03
	END

	SET @JobName04 = N'Baseline - CollectIOVFStats'
	IF EXISTS (SELECT * FROM msdb.dbo.sysjobs WHERE [name] = @JobName04) AND @drop_jobs_if_exist = 1
	BEGIN
		EXEC msdb.dbo.sp_delete_job @job_name = @JobName04, @delete_unused_schedule=1
	END
	IF @CreateJobs = 1
	BEGIN
		/* [sp_CollectIOVFStats] @CollectingInterval  = NULL, @SampleInterval = 30, @Retention = 90, @LogInfo = 1 */
		SET @JobCommand04 = 'sqlcmd -E -S ' + @TokenServer + ' -d ' + DB_NAME() + ' -Q "EXECUTE [dbo].[sp_CollectIOVFStats] @CollectingInterval  = NULL, @SampleInterval = 30, @Retention = 90, @LogInfo = 1" -b'
		SET @OutputFile04 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + 'Baseline_IOVFStats_' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile04) > 200 SET @OutputFile04 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile04) > 200 SET @OutputFile04 = NULL

		EXECUTE msdb.dbo.sp_add_job @job_name = @JobName04, @description = @JobDescription, @category_name = @JobCategory, @owner_login_name = @JobOwner
		EXECUTE msdb.dbo.sp_add_jobstep @job_name = @JobName04, @step_name = @JobName04, @subsystem = 'CMDEXEC', @command = @JobCommand04, @output_file_name = @OutputFile04, @flags=2 
		EXECUTE msdb.dbo.sp_add_jobserver @job_name = @JobName04
	END
	
	SET @JobName05 = N'Baseline - CollectPerfmonData'
	IF EXISTS (SELECT * FROM msdb.dbo.sysjobs WHERE [name] = @JobName05) AND @drop_jobs_if_exist = 1
	BEGIN
		EXEC msdb.dbo.sp_delete_job @job_name = @JobName05, @delete_unused_schedule=1
	END
	IF @CreateJobs = 1
	BEGIN
		/* [sp_CollectPerfmonData] @CollectingInterval = NULL, @SampleInterval = 15, @MeasuringInterval = 5, @Retention = 90, @LogInfo = 1 */
		SET @JobCommand05 = 'sqlcmd -E -S ' + @TokenServer + ' -d ' + DB_NAME() + ' -Q "EXECUTE [dbo].[sp_CollectPerfmonData] @CollectingInterval = NULL, @SampleInterval = 15, @MeasuringInterval = 5, @Retention = 90, @LogInfo = 1" -b'
		SET @OutputFile05 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + 'Baseline_PerfmonData_' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile05) > 200 SET @OutputFile05 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile05) > 200 SET @OutputFile05 = NULL

		EXECUTE msdb.dbo.sp_add_job @job_name = @JobName05, @description = @JobDescription, @category_name = @JobCategory, @owner_login_name = @JobOwner
		EXECUTE msdb.dbo.sp_add_jobstep @job_name = @JobName05, @step_name = @JobName05, @subsystem = 'CMDEXEC', @command = @JobCommand05, @output_file_name = @OutputFile05, @flags=2 
		EXECUTE msdb.dbo.sp_add_jobserver @job_name = @JobName05
	END

	SET @JobName06 = N'Baseline - CollectTempDBUsage'
	IF EXISTS (SELECT * FROM msdb.dbo.sysjobs WHERE [name] = @JobName06) AND @drop_jobs_if_exist = 1
	BEGIN
		EXEC msdb.dbo.sp_delete_job @job_name = @JobName06, @delete_unused_schedule=1
	END
	IF @CreateJobs = 1
	BEGIN
		/* [sp_CollectTempDBUsage] @CollectingInterval = NULL, @SampleInterval = 10, @Retention = 90, @LogInfo = 1 */
		SET @JobCommand06 = 'sqlcmd -E -S ' + @TokenServer + ' -d ' + DB_NAME() + ' -Q "EXECUTE [dbo].[sp_CollectTempDBUsage] @CollectingInterval = NULL, @SampleInterval = 10, @Retention = 90, @LogInfo = 1" -b'
		SET @OutputFile06 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + 'Baseline_TempDBUsage_' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile06) > 200 SET @OutputFile06 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile06) > 200 SET @OutputFile06 = NULL

		EXECUTE msdb.dbo.sp_add_job @job_name = @JobName06, @description = @JobDescription, @category_name = @JobCategory, @owner_login_name = @JobOwner
		EXECUTE msdb.dbo.sp_add_jobstep @job_name = @JobName06, @step_name = @JobName06, @subsystem = 'CMDEXEC', @command = @JobCommand06, @output_file_name = @OutputFile06, @flags=2 
		EXECUTE msdb.dbo.sp_add_jobserver @job_name = @JobName06
	END
	
	SET @JobName07 = N'Baseline - CollectWaitStats'
	IF EXISTS (SELECT * FROM msdb.dbo.sysjobs WHERE [name] = @JobName07) AND @drop_jobs_if_exist = 1
	BEGIN
		EXEC msdb.dbo.sp_delete_job @job_name = @JobName07, @delete_unused_schedule=1
	END
	IF @CreateJobs = 1
	BEGIN
		/* [sp_CollectWaitStats] @ResetWaitStats = 0, @MeasuringInterval = NULL, @Retention = 90, @LogInfo = 1 */
		SET @JobCommand07 = 'sqlcmd -E -S ' + @TokenServer + ' -d ' + DB_NAME() + ' -Q "EXECUTE [dbo].[sp_CollectWaitStats] @ResetWaitStats = 0, @MeasuringInterval = NULL, @Retention = 90, @LogInfo = 1" -b'
		SET @OutputFile07 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + 'Baseline_WaitStats_' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile07) > 200 SET @OutputFile07 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile07) > 200 SET @OutputFile07 = NULL

		EXECUTE msdb.dbo.sp_add_job @job_name = @JobName07, @description = @JobDescription, @category_name = @JobCategory, @owner_login_name = @JobOwner
		EXECUTE msdb.dbo.sp_add_jobstep @job_name = @JobName07, @step_name = @JobName07, @subsystem = 'CMDEXEC', @command = @JobCommand07, @output_file_name = @OutputFile07, @flags=2 
		EXECUTE msdb.dbo.sp_add_jobserver @job_name = @JobName07
	END

	SET @JobName08 = N'Baseline - CollectInstanceInfo'
	IF EXISTS (SELECT * FROM msdb.dbo.sysjobs WHERE [name] = @JobName08) AND @drop_jobs_if_exist = 1
	BEGIN
		EXEC msdb.dbo.sp_delete_job @job_name = @JobName08, @delete_unused_schedule=1
	END
	IF @CreateJobs = 1
	BEGIN
		/* [sp_CollectInstanceInfo] @Retention = 90, @LogInfo = 1 */
		SET @JobCommand08 = 'sqlcmd -E -S ' + @TokenServer + ' -d ' + DB_NAME() + ' -Q "EXECUTE [dbo].[sp_CollectInstanceInfo] @Retention = 90, @LogInfo = 1" -b'
		SET @OutputFile08 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + 'Baseline_InstanceInfo_' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile08) > 200 SET @OutputFile08 = COALESCE(@OutputFileDirectory,@TokenLogDirectory) + '\' + @TokenJobID + '_' + @TokenStepID + '_' + @TokenDate + '.txt'
		IF LEN(@OutputFile08) > 200 SET @OutputFile08 = NULL

		EXECUTE msdb.dbo.sp_add_job @job_name = @JobName08, @description = @JobDescription, @category_name = @JobCategory, @owner_login_name = @JobOwner
		EXECUTE msdb.dbo.sp_add_jobstep @job_name = @JobName08, @step_name = @JobName08, @subsystem = 'CMDEXEC', @command = @JobCommand08, @output_file_name = @OutputFile08, @flags=2 
		EXECUTE msdb.dbo.sp_add_jobserver @job_name = @JobName08
	END
END
GO


/*------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------*/

DROP TABLE #TempConfiguration
GO