/*********************************************************************************************
Comprehensive Baseline Collecting Solution
V1.2 - 2015.05

Written by Robert Virag

BCS_create_schedules.sql

----
Schedules:
	baseline - daily - at 2359PM
	baseline - daily - at 2357PM
	baseline - daily - at 2355PM
	*baseline - daily - at 2353PM
	*baseline - daily - at 2351PM

	*baseline - daily - every 5 mins
	*baseline - daily - every 5 mins - BT/6AM-7PM/
	baseline - daily - every 10 mins
	baseline - daily - every 10 mins - BT/6AM-7PM/
	baseline - daily - every 15 mins
	baseline - daily - every 15 mins - BT/6AM-7PM/
	*baseline - daily - every 30 mins
	*baseline - daily - every 30 mins - BT/6AM-7PM/
	baseline - daily - every 1 hour
	baseline - daily - every 1 hour - BT/6AM-7PM/
	*baseline - daily - every 3 hours /12AM/3AM/6AM/9AM/12PM/3PM/6PM/9PM/
	baseline - daily - every 6 hours /6AM/12PM/6PM/12AM/
	baseline - daily - every 8 hours /6AM/2PM/10PM/
	baseline - daily - evey 12 hours /6AM/6PM/

	*baseline - weekday - every 5 mins
	*baseline - weekday - every 5 mins - BT/6AM-7PM/
	baseline - weekday - every 10 mins
	baseline - weekday - every 10 mins - BT/6AM-7PM/
	baseline - weekday - every 15 mins
	baseline - weekday - every 15 mins - BT/6AM-7PM/
	*baseline - weekday - every 30 mins
	*baseline - weekday - every 30 mins - BT/6AM-7PM/
	baseline - weekday - every 1 hour
	baseline - weekday - every 1 hour - BT/6AM-7PM/
	*baseline - weekday - every 3 hours /12AM/3AM/6AM/9AM/12PM/3PM/6PM/9PM/
	baseline - weekday - every 6 hours /6AM/12PM/6PM/12AM/
	baseline - weekday - every 8 hours /6AM/2PM/10PM/
	baseline - weekday - evey 12 hours /6AM/6PM/

	*baseline - weekend - every 5 mins
	baseline - weekend - every 10 mins
	baseline - weekend - every 15 mins
	baseline - weekend - every 30 mins
	baseline - weekend - every 1 hour
	baseline - weekend - every 3 hours /12AM/3AM/6AM/9AM/12PM/3PM/6PM/9PM/
	baseline - weekend - every 6 hours /6AM/12PM/6PM/12AM/
	baseline - weekend - every 8 hours /6AM/2PM/10PM/
	baseline - weekend - evey 12 hours /6AM/6PM/

----

For scheduling the collectors with agent jobs, Ola Hallengren's code is used
with his permission.

http://ola.hallengren.com/license.html

---

License: The solution is free: http://www.sqlapprentice.net/license/

Copyright (c) 2014 Robert Virag | SQLApprentice.net

Permission is hereby granted, free of charge, to any person 
obtaining a copy of this software and associated documentation 
files (the Software), to deal in the Software without 
restriction, including without limitation the rights to use, 
copy, modify, merge, publish, distribute, sublicense, and/or 
sell copies of the Software, and to permit persons to whom the 
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be 
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED AS IS, WITHOUT WARRANTY OF ANY KIND, 
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES 
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR 
THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*********************************************************************************************/

IF(NOT EXISTS (SELECT [name] FROM [sys].[databases] WHERE [name] = 'BaselineDB'))
BEGIN
	CREATE DATABASE [BaselineDB]
END
GO

IF OBJECT_ID (N'tempdb..#TempConfiguration' ) IS NOT NULL
BEGIN
	DROP TABLE #TempConfiguration
END

CREATE TABLE #TempConfiguration
	(
		[variable] NVARCHAR(128),
		[value] NVARCHAR(max)
	)

USE [BaselineDB]	---------------------------------------------------- modify
GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET NOCOUNT ON
GO

/*--------------------------------------------
-- Settings variables
--------------------------------------------*/
DECLARE @CreateJobs TINYINT
DECLARE @OutputFileDirectory nvarchar(max)
DECLARE @CreateSchedules TINYINT
DECLARE @DropScheduleIfExist TINYINT

DECLARE @SQLCommand NVARCHAR(max)
DECLARE @TableName NVARCHAR(255)
DECLARE @DataCompression BIT
DECLARE @DropTableIfExist BIT


SET @CreateJobs = 1	---------------------------------------------------- modify
/* One log file per day per job will be created */
SET @OutputFileDirectory = N'D:\BaselineLog'	---------------- modify
/* Schedules will be DISABLED and will not be mapped to jobs!!! */
SET @CreateSchedules = 1 ----------------------------------------------- modify


SET @DropTableIfExist = 1	-------------------------------------------- modify
SET @DropScheduleIfExist = 1 ------------------------------------------- modify
SET @DataCompression = 1	-------------------------------------------- modify

INSERT INTO #TempConfiguration ([variable], [value]) VALUES 
(N'@CreateJobs', CAST(@CreateJobs AS nvarchar))
INSERT INTO #TempConfiguration ([variable], [value]) VALUES 
(N'@OutputFileDirectory', @OutputFileDirectory)
INSERT INTO #TempConfiguration ([variable], [value]) VALUES 
(N'@CreateSchedules', CAST(@CreateSchedules AS nvarchar))
INSERT INTO #TempConfiguration ([variable], [value]) VALUES 
(N'@DropScheduleIfExist', CAST(@DropScheduleIfExist AS nvarchar))


/*------------------------------------------------------------------------------------------
-------------------------------------------------------------------------------------------*/
/*********************************************************************************************
Create Schedules
*********************************************************************************************/

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

IF SERVERPROPERTY('EngineEdition') <> 4
BEGIN
	DECLARE @create_schedules TINYINT
	DECLARE @schedule_name SYSNAME
	DECLARE @sa_name SYSNAME
	DECLARE @drop_schedule_if_exist TINYINT

	SELECT @sa_name = [name] FROM sys.server_principals WHERE [sid] = 0x01
	SELECT @create_schedules = CAST(value AS TINYINT) FROM #TempConfiguration WHERE [variable] = N'@CreateSchedules'
	SELECT @drop_schedule_if_exist = CAST(value AS TINYINT) FROM #TempConfiguration WHERE [variable] = N'@DropScheduleIfExist'
	

	SET @schedule_name = 'baseline - daily - at 2359PM'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=1, 
			@freq_subday_interval=0, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=235900, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - at 2357PM'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=1, 
			@freq_subday_interval=0, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=235700, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - at 2355PM'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=1, 
			@freq_subday_interval=0, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=235500, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - at 2353PM'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=1, 
			@freq_subday_interval=0, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=235300, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - at 2351PM'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=1, 
			@freq_subday_interval=0, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=235100, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - every 5 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=4, 
			@freq_subday_interval=5, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - every 5 mins - BT/6AM-7PM/' 
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=4, 
			@freq_subday_interval=5, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - daily - every 10 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=4, 
			@freq_subday_interval=10, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

		
	SET @schedule_name = 'baseline - daily - every 10 mins - BT/6AM-7PM/' 
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=4, 
			@freq_subday_interval=10, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - every 15 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=4, 
			@freq_subday_interval=15, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - every 15 mins - BT/6AM-7PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=4, 
			@freq_subday_interval=15, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - every 30 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=4, 
			@freq_subday_interval=30, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - every 30 mins - BT/6AM-7PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=4, 
			@freq_subday_interval=30, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - daily - every 1 hour'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,		 
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=8, 
			@freq_subday_interval=1, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - every 1 hour - BT/6AM-7PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=8, 
			@freq_subday_interval=1, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - daily - every 3 hours /12AM/3AM/6AM/9AM/12PM/3PM/6PM/9PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=8, 
			@freq_subday_interval=3, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - daily - every 6 hours /6AM/12PM/6PM/12AM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=8, 
			@freq_subday_interval=6, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - daily - every 8 hours /6AM/2PM/10PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=8, 
			@freq_subday_interval=8, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END

	
	SET @schedule_name = 'baseline - daily - evey 12 hours /6AM/6PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=4, 
			@freq_interval=1, 
			@freq_subday_type=8, 
			@freq_subday_interval=12, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - weekday - every 5 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=4, 
			@freq_subday_interval=5, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - weekday - every 5 mins - BT/6AM-7PM/' 
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=4, 
			@freq_subday_interval=5, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - weekday - every 10 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=4, 
			@freq_subday_interval=10, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekday - every 10 mins - BT/6AM-7PM/' 
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=4, 
			@freq_subday_interval=10, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekday - every 15 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=4, 
			@freq_subday_interval=15, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekday - every 15 mins - BT/6AM-7PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=4, 
			@freq_subday_interval=15, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - weekday - every 30 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=4, 
			@freq_subday_interval=30, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - weekday - every 30 mins - BT/6AM-7PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=4, 
			@freq_subday_interval=30, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - weekday - every 1 hour'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,		 
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=8, 
			@freq_subday_interval=1, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekday - every 1 hour - BT/6AM-7PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=8, 
			@freq_subday_interval=1, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=190000,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekday - evey 3 hours /12AM/3AM/6AM/9AM/12PM/3PM/6PM/9PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=8, 
			@freq_subday_interval=3, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekday - every 6 hours /6AM/12PM/6PM/12AM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=8, 
			@freq_subday_interval=6, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekday - every 8 hours /6AM/2PM/10PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=8, 
			@freq_subday_interval=8, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekday - evey 12 hours /6AM/6PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=62, 
			@freq_subday_type=8, 
			@freq_subday_interval=12, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - weekend - every 5 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=65, 
			@freq_subday_type=4, 
			@freq_subday_interval=5, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END


	SET @schedule_name = 'baseline - weekend - every 10 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=65, 
			@freq_subday_type=4, 
			@freq_subday_interval=10, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekend - every 15 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=65, 
			@freq_subday_type=4, 
			@freq_subday_interval=15, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekend - every 30 mins'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=65, 
			@freq_subday_type=4, 
			@freq_subday_interval=30, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekend - every 1 hour'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,		 
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=65, 
			@freq_subday_type=8, 
			@freq_subday_interval=1, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekend - every 3 hours /12AM/3AM/6AM/9AM/12PM/3PM/6PM/9PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,		 
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=65, 
			@freq_subday_type=8, 
			@freq_subday_interval=3, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=0, 
			@active_end_time=235959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekend - every 6 hours /6AM/12PM/6PM/12AM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=65, 
			@freq_subday_type=8, 
			@freq_subday_interval=6, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekend - every 8 hours /6AM/2PM/10PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=65, 
			@freq_subday_type=8, 
			@freq_subday_interval=8, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END

	SET @schedule_name = 'baseline - weekend - evey 12 hours /6AM/6PM/'
	IF @drop_schedule_if_exist = 1 AND EXISTS (SELECT * FROM [msdb].[dbo].[sysschedules] WHERE [name] = @schedule_name)
		BEGIN
			EXEC msdb.dbo.sp_delete_schedule  @schedule_name = @schedule_name
		END
	IF(@create_schedules = 1)
	BEGIN
		EXEC msdb.dbo.sp_add_schedule
			@schedule_name = @schedule_name,
			@enabled=0, 
			@freq_type=8, 
			@freq_interval=65, 
			@freq_subday_type=8, 
			@freq_subday_interval=12, 
			@freq_relative_interval=0, 
			@freq_recurrence_factor=1, 
			@active_start_date=20140915, 
			@active_end_date=99991231, 
			@active_start_time=60000, 
			@active_end_time=55959,
			@owner_login_name = @sa_name
	END
END
GO

DROP TABLE #TempConfiguration