/*********************************************************************************************
Comprehensive Baseline Collecting Solution
V1.2 - 2015.05

Written by Robert Virag

BCS_create_schema.sql

----

For scheduling the collectors with agent jobs, Ola Hallengren's code is used
with his permission.

http://ola.hallengren.com/license.html

License:

Copyright (c) 2014 Robert Virag | SQLApprentice.net

Permission is hereby granted, free of charge, to any person 
obtaining a copy of this software and associated documentation 
files (the Software), to deal in the Software without 
restriction, including without limitation the rights to use, 
copy, modify, merge, publish, distribute, sublicense, and/or 
sell copies of the Software, and to permit persons to whom the 
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be 
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED AS IS, WITHOUT WARRANTY OF ANY KIND, 
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES 
OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR 
THE USE OR OTHER DEALINGS IN THE SOFTWARE.

*********************************************************************************************/

IF(NOT EXISTS (SELECT [name] FROM [sys].[databases] WHERE [name] = 'BaselineDB'))
BEGIN
	CREATE DATABASE [BaselineDB]
END
GO

/*--------------------------------------------
-- Create Baseline Schema 
--------------------------------------------*/
USE [BaselineDB]
GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET NOCOUNT ON
GO

DECLARE @SQLCommand NVARCHAR(max)
DECLARE @TableName NVARCHAR(255)
DECLARE @DataCompression BIT
DECLARE @DropTableIfExist BIT

SET @DropTableIfExist = 1
SET @DataCompression = 1


/*--------------------------------------------
-- Create Table for Instance Info 
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[instance_info]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[instance_info]
END
SET @SQLCommand = N'CREATE TABLE [dbo].[instance_info]
	(
		[capture_date] DATETIME NOT NULL,
		[name] NVARCHAR(50) NOT NULL,
		[value] SQL_VARIANT NULL,
		[is_initial] BIT NOT NULL, 
		[is_pre] BIT NOT NULL 
	) '

IF(@@VERSION NOT LIKE N'%Microsoft SQL Server 2000%' AND @@VERSION NOT LIKE N'%Microsoft SQL Server 2005%' AND @DataCompression = 1 AND (CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Enterprise%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Developer%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Data Center%'))
BEGIN
	SET @SQLCommand = @SQLCommand + N' WITH (DATA_COMPRESSION = PAGE)'
END

EXEC sp_executesql @SQLCommand

CREATE UNIQUE CLUSTERED INDEX [CI_instance_info] ON [dbo].[instance_info] ([capture_date],[name])


/*--------------------------------------------
-- Create Table for Server Configuration 
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[configuration_data]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[configuration_data]
END
SET @SQLCommand = N'CREATE TABLE [dbo].[configuration_data]
	(
		[capture_date] DATETIME NOT NULL,
		[configuration_id] INT NOT NULL,
		[value] SQL_VARIANT NULL,
		[value_in_use] SQL_VARIANT NULL,
		[is_initial] BIT, 
		[is_pre] BIT 
	) '

IF(@@VERSION NOT LIKE N'%Microsoft SQL Server 2000%' AND @@VERSION NOT LIKE N'%Microsoft SQL Server 2005%' AND @DataCompression = 1 AND (CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Enterprise%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Developer%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Data Center%'))
BEGIN
	SET @SQLCommand = @SQLCommand + N' WITH (DATA_COMPRESSION = PAGE)'
END

EXEC sp_executesql @SQLCommand

CREATE UNIQUE CLUSTERED INDEX [CI_configuration_data] ON [dbo].[configuration_data] ([capture_date],[configuration_id])

/*--------------------------------------------
-- Create Table for Database Info 
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[database_info]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[database_info]
END
SET @SQLCommand = N'CREATE TABLE [dbo].[database_info]
	(
		[capture_date] DATETIME,
		[database_name] SYSNAME,
		[database_id] INT,
		[source_database_id] INT,
		[owner_sid] VARBINARY(85),
		[create_date] DATETIME,
		[compatibility_level] TINYINT,
		[collation_name] NVARCHAR(128),
		[user_access] TINYINT,
		[is_read_only] BIT,
		[is_auto_close_on] BIT,
		[is_auto_shrink_on] BIT,
		[state] TINYINT,
		[is_in_standby] BIT,
		[is_supplemental_logging_enabled] BIT,
		[snapshot_isolation_state] TINYINT,
		[is_read_committed_snapshot_on] BIT,
		[recovery_model] TINYINT,
		[page_verify_option] TINYINT,
		[is_auto_create_stats_on] BIT,
		[is_auto_update_stats_on] BIT,
		[is_auto_update_stats_async_on] BIT,
		[is_ansi_null_default_on] BIT,
		[is_ansi_nulls_on] BIT,
		[is_ansi_padding_on] BIT,
		[is_ansi_warnings_on] BIT,
		[is_arithabort_on] BIT,
		[is_concat_null_yields_null_on] BIT,
		[is_numeric_roundabort_on] BIT,
		[is_quoted_identifier_on] BIT,
		[is_recursive_triggers_on] BIT,
		[is_cursor_close_on_commit_on] BIT,
		[is_local_cursor_default] BIT,
		[is_fulltext_enabled] BIT,
		[is_trustworthy_on] BIT,
		[is_db_chaining_on] BIT,
		[is_parameterization_forced] BIT,
		[is_master_key_encrypted_by_server] BIT,
		[is_published] BIT,
		[is_merge_published] BIT,
		[is_distributor] BIT,
		[is_sync_with_backup] BIT,
		[service_broker_guid] UNIQUEIDENTIFIER,
		[is_broker_enabled] BIT,
		[is_date_correlation_on] BIT '

IF(@@VERSION LIKE N'%Microsoft SQL Server 2005%')
BEGIN
	SET @SQLCommand = @SQLCommand + N',
	[is_initial] BIT, 
	[is_pre] BIT 
	) '
END

IF(@@VERSION LIKE N'%Microsoft SQL Server 2008%')
BEGIN
	SET @SQLCommand = @SQLCommand + N',
	/*2008*/
	[is_cdc_enabled] BIT, 
	[is_encrypted] BIT, 
	[is_honor_broker_priority_on] BIT, 
	[is_initial] BIT, 
	[is_pre] BIT
	) '
END

IF(@@VERSION LIKE N'%Microsoft SQL Server 2012%')
BEGIN
	SET @SQLCommand = @SQLCommand + N',
	/*2008*/
	[is_cdc_enabled] BIT,
	[is_encrypted] BIT,
	[is_honor_broker_priority_on] BIT,
	/*2012*/
	[replica_id] UNIQUEIDENTIFIER,
	[group_database_id] UNIQUEIDENTIFIER,
	[default_language_lcid] SMALLINT, 
	[default_fulltext_language_lcid] INT, 
	[is_nested_triggers_on] BIT, 
	[is_transform_noise_words_on] BIT,
	[two_digit_year_cutoff] SMALLINT, 
	[containment] TINYINT,  
	[target_recovery_time_in_seconds] INT, 
	[is_initial] BIT, 
	[is_pre] BIT
	) '
END

IF(@@VERSION LIKE N'%Microsoft SQL Server 2014%')
BEGIN
	SET @SQLCommand = @SQLCommand + N',
	/*2008*/
	[is_cdc_enabled] BIT,
	[is_encrypted] BIT,
	[is_honor_broker_priority_on] BIT,
	/*2012*/
	[replica_id] UNIQUEIDENTIFIER,
	[group_database_id] UNIQUEIDENTIFIER,
	[default_language_lcid] SMALLINT, 
	[default_fulltext_language_lcid] INT, 
	[is_nested_triggers_on] BIT, 
	[is_transform_noise_words_on] BIT,
	[two_digit_year_cutoff] SMALLINT, 
	[containment] TINYINT,  
	[target_recovery_time_in_seconds] INT,
	/*2014*/
	[is_auto_create_stats_incremental_on] BIT, 
	[is_query_store_on] BIT, 
	[resource_pool_id] INT, 
	[delayed_durability] INT,
	[is_memory_optimized_elevate_to_snapshot_on] BIT,
	[is_initial] BIT, 
	[is_pre] BIT 
	) '
END

IF(@@VERSION NOT LIKE N'%Microsoft SQL Server 2000%' AND @@VERSION NOT LIKE N'%Microsoft SQL Server 2005%' AND @DataCompression = 1 AND (CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Enterprise%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Developer%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Data Center%'))
BEGIN
	SET @SQLCommand = @SQLCommand + N' WITH (DATA_COMPRESSION = PAGE)'	
END

EXEC sp_executesql @SQLCommand

CREATE UNIQUE CLUSTERED INDEX [CI_database_info] ON [dbo].[database_info] ([capture_date], [database_name])

/*--------------------------------------------
-- Create Table for File Info 
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[file_info]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[file_info]
END
IF(OBJECT_ID('[dbo].[ts_file_info]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[ts_file_info]
END
SET @SQLCommand = N'CREATE TABLE [dbo].[file_info]
	(
		[capture_date] DATETIME,
		[database_name] SYSNAME,
		[physical_name] NVARCHAR(260),
		[type] TINYINT,
		[size_pages] INT,
		[space_used_pages] INT,
		[max_size_pages] INT,
		[growth_pages_percent] INT,
		[is_percent_growth] BIT
	) '
IF(@@VERSION NOT LIKE N'%Microsoft SQL Server 2000%' AND @@VERSION NOT LIKE N'%Microsoft SQL Server 2005%' AND @DataCompression = 1 AND (CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Enterprise%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Developer%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Data Center%'))
BEGIN
	SET @SQLCommand = @SQLCommand + N' WITH (DATA_COMPRESSION = PAGE)'	
END

EXEC sp_executesql @SQLCommand

SET @SQLCommand = REPLACE(@SQLCommand, N'[file_info]', N'[ts_file_info]')

EXEC sp_executesql @SQLCommand

CREATE UNIQUE CLUSTERED INDEX [CI_file_info] ON [dbo].[file_info] ([capture_date],[physical_name])

CREATE UNIQUE CLUSTERED INDEX [CI_ts_file_info] ON [dbo].[ts_file_info] ([capture_date],[physical_name])

/*--------------------------------------------
-- Create Table for IO Virtual File Stats
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[iovf_stats]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[iovf_stats]
END
IF(OBJECT_ID('[dbo].[ts_iovf_stats]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[ts_iovf_stats]
END
SET @SQLCommand = N'CREATE TABLE [dbo].[iovf_stats]
	(
		[capture_date] DATETIME,
		[database_name] SYSNAME,
		[type] TINYINT,
		[physical_name] NVARCHAR(260),
		[sample_ms] INT,
		[num_of_reads] BIGINT,
		[num_of_bytes_read] BIGINT,
		[io_stall_read_ms] BIGINT,
		[num_of_writes] BIGINT,
		[num_of_bytes_written] BIGINT,
		[io_stall_write_ms] BIGINT
	) '

IF(@@VERSION NOT LIKE N'%Microsoft SQL Server 2000%' AND @@VERSION NOT LIKE N'%Microsoft SQL Server 2005%' AND @DataCompression = 1 AND (CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Enterprise%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Developer%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Data Center%'))
BEGIN
	SET @SQLCommand = @SQLCommand + N' WITH (DATA_COMPRESSION = PAGE)'
END

EXEC sp_executesql @SQLCommand

SET @SQLCommand = REPLACE(@SQLCommand, N'[iovf_stats]', N'[ts_iovf_stats]')

EXEC sp_executesql @SQLCommand

CREATE UNIQUE CLUSTERED INDEX [CI_iovf_stats] ON [dbo].[iovf_stats] ([capture_date],[physical_name])

CREATE UNIQUE CLUSTERED INDEX [CI_ts_iovf_stats] ON [dbo].[ts_iovf_stats] ([capture_date],[physical_name])

/*-------------------------------------------------------
-- Table for Filtering Database's Files
-------------------------------------------------------*/
IF(OBJECT_ID('[dbo].[filter_database_file]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[filter_database_file]
END
CREATE TABLE [dbo].[filter_database_file]
(
	[id] INT IDENTITY(1,1),
	[database_name] SYSNAME,
	[logical_file_name] SYSNAME,
	[is_excluded_file_info] BIT, 
	[ts_is_included_file_info] BIT,
	[is_excluded_iovf] BIT,
	[ts_is_included_iovf] BIT
)

/*--------------------------------------------
-- Insert all databases
--------------------------------------------*/
INSERT INTO [dbo].[filter_database_file]
( [database_name], [logical_file_name], [is_excluded_file_info], [ts_is_included_file_info], [is_excluded_iovf], [ts_is_included_iovf] )
SELECT DB_NAME(database_id), name, 0, 0, 0, 0 FROM sys.master_files


/*--------------------------------------------
-- Create Table for TempDB Usage
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[tempdb_usage]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[tempdb_usage]
END
IF(OBJECT_ID('[dbo].[ts_tempdb_usage]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[ts_tempdb_usage]
END
SET @SQLCommand = N'CREATE TABLE [dbo].[tempdb_usage]
	( 
		[capture_date] DATETIME,
		[file_id] SMALLINT,
		[drive] NCHAR(1),
		[unallocated_extent_page_count] BIGINT,
		[version_store_reserved_page_count] BIGINT,
		[user_object_reserved_page_count] BIGINT,
		[internal_object_reserved_page_count] BIGINT,
		[mixed_extent_page_count] BIGINT
	) '

IF(@@VERSION NOT LIKE N'%Microsoft SQL Server 2000%' AND @@VERSION NOT LIKE N'%Microsoft SQL Server 2005%' AND @DataCompression = 1 AND (CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Enterprise%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Developer%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Data Center%'))
BEGIN
	SET @SQLCommand = @SQLCommand + N' WITH (DATA_COMPRESSION = PAGE)'
END

EXEC sp_executesql @SQLCommand

SET @SQLCommand = REPLACE(@SQLCommand, N'[tempdb_usage]', N'[ts_tempdb_usage]')

EXEC sp_executesql @SQLCommand

CREATE UNIQUE CLUSTERED INDEX [CI_tempdb_usage] ON [dbo].[tempdb_usage] ([capture_date],[file_id])

CREATE UNIQUE CLUSTERED INDEX [CI_ts_tempdb_usage] ON [dbo].[ts_tempdb_usage] ([capture_date],[file_id])
		
/*--------------------------------------------
-- Create Table for PerfMon Data
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[perfmon_data]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[perfmon_data]
END
IF(OBJECT_ID('[dbo].[ts_perfmon_data]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[ts_perfmon_data]
END
SET @SQLCommand = N'CREATE TABLE [dbo].[perfmon_data]
	(
		[capture_date] DATETIME,
		[counter] NVARCHAR(255),
		[value] DECIMAL(32,2)
	) '

IF(@@VERSION NOT LIKE N'%Microsoft SQL Server 2000%' AND @@VERSION NOT LIKE N'%Microsoft SQL Server 2005%' AND @DataCompression = 1 AND (CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Enterprise%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Developer%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Data Center%'))
BEGIN
	SET @SQLCommand = @SQLCommand + N' WITH (DATA_COMPRESSION = PAGE)'
END

EXEC sp_executesql @SQLCommand

SET @SQLCommand = REPLACE(@SQLCommand, N'[perfmon_data]', N'[ts_perfmon_data]')

EXEC sp_executesql @SQLCommand

CREATE UNIQUE CLUSTERED INDEX [CI_perfmon_data] ON [dbo].[perfmon_data] ([capture_date],[counter])

CREATE UNIQUE CLUSTERED INDEX [CI_ts_perfmon_data] ON [dbo].[ts_perfmon_data] ([capture_date],[counter])

/*--------------------------------------------
-- Create Table for Wait Stats
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[wait_stats]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[wait_stats]
END
IF(OBJECT_ID('[dbo].[ts_wait_stats]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[ts_wait_stats]
END
SET @SQLCommand = N'CREATE TABLE [dbo].[wait_stats]
	(
		[capture_date] DATETIME,
		[wait_type] NVARCHAR(60),
		[waiting_tasks_count] BIGINT,
		[wait_time_ms] BIGINT,
		[max_wait_time_ms] BIGINT,
		[signal_wait_time_ms] BIGINT
	) '

IF(@@VERSION NOT LIKE N'%Microsoft SQL Server 2000%' AND @@VERSION NOT LIKE N'%Microsoft SQL Server 2005%' AND @DataCompression = 1 AND (CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Enterprise%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Developer%' OR CAST(SERVERPROPERTY(N'edition') AS NVARCHAR(100)) LIKE N'%Data Center%'))
BEGIN
	SET @SQLCommand = @SQLCommand + N' WITH (DATA_COMPRESSION = PAGE)'
END

EXEC sp_executesql @SQLCommand

SET @SQLCommand = REPLACE(@SQLCommand, N'[wait_stats]', N'[ts_wait_stats]')

EXEC sp_executesql @SQLCommand

CREATE UNIQUE CLUSTERED INDEX [CI_wait_stats] ON [dbo].[wait_stats] ([capture_date],[wait_type])

CREATE UNIQUE CLUSTERED INDEX [CI_ts_wait_stats] ON [dbo].[ts_wait_stats] ([capture_date],[wait_type])

/*--------------------------------------------
-- Table for Filtering WaitStats
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[filter_wait_types]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[filter_wait_types]
END
CREATE TABLE [dbo].[filter_wait_types]
(
	[id] INT IDENTITY(1,1),
	[wait_type] NVARCHAR(60),
	[is_excluded] BIT,
	[ts_is_excluded] BIT
)

IF (@@VERSION LIKE N'%Microsoft SQL Server 2005%' 
	OR (@@VERSION LIKE N'%Microsoft SQL Server 2008%' 
		AND @@VERSION NOT LIKE N'%Microsoft SQL Server 2008 R2%')) 
BEGIN
	INSERT INTO [dbo].[filter_wait_types]
	( [wait_type], [is_excluded], [ts_is_excluded] )
	VALUES ('AI_SQLTRACE_INCREMENTAL_FLUSH_SLEEP', 0, 0)
END

INSERT INTO [dbo].[filter_wait_types]
( [wait_type], [is_excluded], [ts_is_excluded] )
SELECT [wait_type], 0, 0 FROM sys.dm_os_wait_stats

---------------------------------------------------------------------------------------------------------------------------------------
-- Set exclude list if no list provided by user then it uses Paul Randal's code
-- (2014 marc) - http://www.sqlskills.com/blogs/paul/wait-statistics-or-please-tell-me-where-it-hurts/
---------------------------------------------------------------------------------------------------------------------------------------	
UPDATE [dbo].[filter_wait_types]
SET [is_excluded] =  1,
[ts_is_excluded] = 1 WHERE [wait_type] IN (
			N'BROKER_EVENTHANDLER',
			N'BROKER_RECEIVE_WAITFOR',
			N'BROKER_TASK_STOP',
			N'BROKER_TO_FLUSH',
			N'BROKER_TRANSMITTER',
			N'CHECKPOINT_QUEUE',
			N'CHKPT',
			N'CLR_AUTO_EVENT',
			N'CLR_MANUAL_EVENT',
			N'CLR_SEMAPHORE',
			N'DBMIRROR_DBM_EVENT',
			N'DBMIRROR_EVENTS_QUEUE',
			N'DBMIRROR_WORKER_QUEUE',
			N'DBMIRRORING_CMD',
			N'DIRTY_PAGE_POLL',
			N'DISPATCHER_QUEUE_SEMAPHORE',
			N'EXECSYNC',
			N'FSAGENT',
			N'FT_IFTS_SCHEDULER_IDLE_WAIT',
			N'FT_IFTSHC_MUTEX',
			N'HADR_CLUSAPI_CALL',
			N'HADR_FILESTREAM_IOMGR_IOCOMPLETION',
			N'HADR_LOGCAPTURE_WAIT',
			N'HADR_NOTIFICATION_DEQUEUE',
			N'HADR_TIMER_TASK',
			N'HADR_WORK_QUEUE',
			N'KSOURCE_WAKEUP',
			N'LAZYWRITER_SLEEP',
			N'LOGMGR_QUEUE',
			N'ONDEMAND_TASK_QUEUE',
			N'PWAIT_ALL_COMPONENTS_INITIALIZED',
			N'QDS_PERSIST_TASK_MAIN_LOOP_SLEEP',
			N'QDS_CLEANUP_STALE_QUERIES_TASK_MAIN_LOOP_SLEEP',
			N'REQUEST_FOR_DEADLOCK_SEARCH',
			N'RESOURCE_QUEUE',
			N'SERVER_IDLE_CHECK',
			N'SLEEP_BPOOL_FLUSH',
			N'SLEEP_DBSTARTUP',
			N'SLEEP_DCOMSTARTUP',
			N'SLEEP_MASTERDBREADY',
			N'SLEEP_MASTERMDREADY',
			N'SLEEP_MASTERUPGRADED',
			N'SLEEP_MSDBSTARTUP',
			N'SLEEP_SYSTEMTASK',
			N'SLEEP_TASK',
			N'SLEEP_TEMPDBSTARTUP',
			N'SNI_HTTP_ACCEPT',
			N'SP_SERVER_DIAGNOSTICS_SLEEP',
			N'SQLTRACE_BUFFER_FLUSH',
			--N'SQLTRACE_INCREMENTAL_FLUSH_SLEEP',
			N'SQLTRACE_WAIT_ENTRIES',
			N'WAIT_FOR_RESULTS',
			N'WAITFOR',
			N'WAITFOR_TASKSHUTDOWN',
			N'WAIT_XTP_HOST_WAIT',
			N'WAIT_XTP_OFFLINE_CKPT_NEW_LOG',
			N'WAIT_XTP_CKPT_CLOSE',
			N'XE_DISPATCHER_JOIN',
			N'XE_DISPATCHER_WAIT',
			N'XE_TIMER_EVENT' )

/*--------------------------------------------
-- Table for Filtering PerfMon Counters
--------------------------------------------*/
IF(OBJECT_ID('[dbo].[filter_performance_counters]') IS NOT NULL AND @DropTableIfExist = 1)
BEGIN
	DROP TABLE [dbo].[filter_performance_counters]
END
CREATE TABLE [dbo].[filter_performance_counters]
(
	[id] INT IDENTITY(1,1),
	[counter_name] NVARCHAR(60),
	[is_included] BIT,
	[ts_is_included] BIT
)

/*--------------------------------------------
-- Insert all supported counters
--------------------------------------------*/
INSERT INTO [dbo].[filter_performance_counters]
( [counter_name], [is_included], [ts_is_included] )
SELECT DISTINCT [counter_name], 0, 0 FROM sys.dm_os_performance_counters WHERE cntr_type IN (272696576, 65792)

/*------------------------------------------------------------------------------------
-- My preferred list of counters mixed up from different source 
-- Use this poster to interpret the counters: 
-- http://www.quest.com/backstage/images/promotions/SQLServer-Perfmonance-Poster.pdf
------------------------------------------------------------------------------------*/
/*
	http://blogs.msdn.com/b/sqlosteam/archive/2012/07/11/memory-manager-surface-area-changes-in-sql-server-2012.aspx
	N'Free Pages' /-2008r2/		=>	N'Free Memory (KB)' /2012+/
	N'Target Pages'	/-2014/		=>	N'Target Server Memory (KB)' /-2014/
	N'Total Pages' /-2008r2/	=>	N'Total Server Memory (KB)' /-2014/
	N'Stolen Pages'	/-2008r2/	=>	N'Stolen Server Memory (KB)' /2012+/
	N'Database Pages' /-2014/	=>	N'Database Cache Memory (KB)' /2012+/
*/
IF(@@VERSION LIKE N'%Microsoft SQL Server 2012%' OR @@VERSION  LIKE N'%Microsoft SQL Server 2014%')
BEGIN
	UPDATE [dbo].[filter_performance_counters]
	SET [is_included] =  1, 
	[ts_is_included] = 1 WHERE [counter_name] IN (
			/* Data Access Performance Counters */
			N'Forwarded Records/sec',
			N'Index Searches/sec',
			N'Full Scans/sec',
			N'Page Splits/sec',
			/* Memory Manager Counters */
			/* "How is My Memory Being Used" Performance Counters */
			N'Total Server Memory (KB)', --*
			N'Target Server Memory (KB)', --*
			N'Free Memory (KB)', --*
			N'Stolen Server Memory (KB)', --*
			N'Database Cache Memory (KB)', --*
			N'Memory Grants Pending',			
			/* Buffer Manager and Memory Performance Counters */
			N'Free list stalls/sec',
			N'Lazy writes/sec',
			N'Checkpoint Pages/sec',
			N'Page life expectancy',
			N'Page reads/sec',
			N'Page writes/sec',			
			/* Workload Performance Counters */
			N'Batch Requests/sec',
			N'SQL Compilations/sec',
			N'SQL Re-Compilations/sec',
			/* Users and Locks Performance Counters */
			N'User Connections',
			N'Latch Waits/sec',
			N'Number of Deadlocks/sec',
			N'Transactions/sec',
			N'Lock Waits/sec' )
END
ELSE
BEGIN
UPDATE [dbo].[filter_performance_counters]
	SET [is_included] =  1, 
	[ts_is_included] = 1 WHERE [counter_name] IN (
			/* Data Access Performance Counters */
			N'Forwarded Records/sec',
			N'Index Searches/sec',
			N'Full Scans/sec',
			N'Page Splits/sec',
			/* Memory Manager Counters */
			/* "How is My Memory Being Used" Performance Counters */
			N'Total Server Memory (KB)', --*
			N'Total Pages', --*
			N'Target Server Memory (KB)', --*
			N'Target Pages', --*
			N'Free Memory (KB)', --*
			N'Free Pages', --*
			N'Stolen Server Memory (KB)', --*
			N'Stolen Pages', --*
			N'Database Cache Memory (KB)', --*
			N'Database Pages',--*
			N'Memory Grants Pending',			
			/* Buffer Manager and Memory Performance Counters */
			N'Free list stalls/sec',
			N'Lazy writes/sec',
			N'Checkpoint Pages/sec',
			N'Page life expectancy',
			N'Page reads/sec',
			N'Page writes/sec',			
			/* Workload Performance Counters */
			N'Batch Requests/sec',
			N'SQL Compilations/sec',
			N'SQL Re-Compilations/sec',
			/* Users and Locks Performance Counters */
			N'User Connections',
			N'Latch Waits/sec',
			N'Number of Deadlocks/sec',
			N'Transactions/sec',
			N'Lock Waits/sec' )
END